@@ -10,6 +10,7 @@ from adafruit_epd.il91874 import Adafruit_IL91874  # pylint: disable=unused-impo
 from adafruit_epd.il0398 import Adafruit_IL0398  # pylint: disable=unused-import
 from adafruit_epd.ssd1608 import Adafruit_SSD1608  # pylint: disable=unused-import
 from adafruit_epd.ssd1675 import Adafruit_SSD1675  # pylint: disable=unused-import
+from adafruit_epd.ssd1681 import Adafruit_SSD1681  # pylint: disable=unused-import
 
 # create the spi device and pins we will need
 spi = busio.SPI(board.SCK, MOSI=board.MOSI, MISO=board.MISO)
@@ -19,18 +20,19 @@ srcs = digitalio.DigitalInOut(board.D10)  # can be None to use internal memory
 rst = digitalio.DigitalInOut(board.D9)  # can be None to not use this pin
 busy = digitalio.DigitalInOut(board.D5)  # can be None to not use this pin
 
-# give them all to our driver
+# give them all to our drivers
 print("Creating display")
-# display = Adafruit_SSD1608(200, 200, spi,        # 1.54" HD mono display
-# display = Adafruit_SSD1675(122, 250, spi,        # 2.13" HD mono display
-# display = Adafruit_IL91874(176, 264, spi,        # 2.7" Tri-color display
-# display = Adafruit_IL0373(152, 152, spi,         # 1.54" Tri-color display
-# display = Adafruit_IL0373(128, 296, spi,         # 2.9" Tri-color display
-# display = Adafruit_IL0398(400, 300, spi,         # 4.2" Tri-color display
+# display = Adafruit_SSD1608(200, 200,        # 1.54" HD mono display
+# display = Adafruit_SSD1675(122, 250,        # 2.13" HD mono display
+# display = Adafruit_SSD1681(200, 200,        # 1.54" HD Tri-color display
+# display = Adafruit_IL91874(176, 264,        # 2.7" Tri-color display
+# display = Adafruit_IL0373(152, 152,         # 1.54" Tri-color display
+# display = Adafruit_IL0373(128, 296,         # 2.9" Tri-color display
+# display = Adafruit_IL0398(400, 300,         # 4.2" Tri-color display
 display = Adafruit_IL0373(
     104,
-    212,
-    spi,  # 2.13" Tri-color display
+    212,  # 2.13" Tri-color display
+    spi,
     cs_pin=ecs,
     dc_pin=dc,
     sramcs_pin=srcs,
